#include "testlib.h"
#include <iostream>
#include <vector>
#include <set>

using namespace std;

struct Result {
  bool found; // partition found?
  string ans; // partition
  bool ansValid; // is the partition valid?
};

bool valid (const vector<pair<int, int>> &vec) {
  set<int> seen;
  for (auto e : vec) {
    if (seen.count(e.first))
      return false;
    seen.insert(e.first);

    if (seen.count(e.second))
      return false;
    seen.insert(e.second);
  }

  return true;
}

Result readAndCheckAnswer (InStream &in, const vector<pair<int, int>> &edges) {
  Result result;
  
  string exists = in.readToken("(JAH)|(EI)");
  result.found = exists == string("JAH");

  if (!result.found)
    return result;

  result.ans = in.readToken();
  for (char c : result.ans)
    if (c != 'A' && c != 'B')
      in.quitf(_pe, "character is not A or B");
  
  if (result.ans.size() != edges.size())
    in.quitf(_pe, "length of string is not n");

  vector<pair<int, int>> A, B;
  for (int i = 0; i < (int) edges.size(); i++) {
    if (result.ans[i] == 'A')
      A.push_back(edges[i]);
    else
      B.push_back(edges[i]);
  }

  result.ansValid = valid(A) && valid(B);
  return result;
}

int main (int argc, char **argv) {
  registerTestlibCmd(argc, argv);

  int n = inf.readInt();
  vector<pair<int, int>> edges (n);
  for (int i = 0; i < n; i++) {
    edges[i].first = inf.readInt();
    edges[i].second = inf.readInt();
  }

  Result ja = readAndCheckAnswer(ans, edges);
  Result pa = readAndCheckAnswer(ouf, edges);

  if (ja.found) {
    if (!ja.ansValid)
      quitf(_fail, "jury has an invalid solution");
    
    if (!pa.found)
      quitf(_wa, "jury has solution, participant doesn't");

    if (!pa.ansValid)
      quitp(0.5, "correct answer but invalid construction");

    if (ja.ans < pa.ans)
      quitp(0.75, "correct answer but lexicographically not minimal construction");

    if (pa.ans < ja.ans)
      quitf(_fail, "participant has a lexicographically better solution than jury");

    quitf(_ok, "OK");
  }

  if (pa.found) {
    if (pa.ansValid)
      quitf(_fail, "participant has a solution, jury doesn't");

    quitf(_wa, "wrong answer");
  }

  quitf(_ok, "OK");
}
