#include <iostream>
#include <vector>
#include <map>
#include <cassert>
#include <algorithm>

using namespace std;

void fail () {
  cout << "EI" << endl;
  exit(0);
}

const int MAX_N = 4e5 + 5;

vector<pair<int, int>> adj [MAX_N];

int side [MAX_N];
bool edge_vis [MAX_N];

void dfs (int u, int cur_side, vector<int> &A, vector<int> &B) {
  side[u] = cur_side;

  bool edge_found = false;
  for (auto pr : adj[u]) {
    int nxt = pr.first;
    int id = pr.second;

    if (side[nxt] == cur_side)
      fail(); // graph is not bipartite

    if (!edge_vis[id]) {
      assert(!edge_found); // dfs order should ensure that
      A.push_back(id);
      edge_vis[id] = 1;
      if (!side[nxt]) {
        dfs(nxt, -cur_side, B, A);
      }
      edge_found = true;
    }
  }
}

int main () {
  ios::sync_with_stdio(false);
  cin.tie(0);

  int m;
  cin >> m;

  vector<pair<int, int>> edges (m);
  for (int i = 0; i < m; i++) {
    cin >> edges[i].first >> edges[i].second;
  }

  map<int, int> compr;
  for (auto e : edges) {
    compr[e.first] = 0;
    compr[e.second] = 0;
  }

  int n = 0;
  for (auto it = compr.begin(); it != compr.end(); it++) {
    it->second = n;
    n++;
  }

  for (auto &e : edges) {
    e.first = compr[e.first];
    e.second = compr[e.second];
  }

  for (int i = 0; i < m; i++) {
    int u = edges[i].first;
    int v = edges[i].second;

    adj[u].emplace_back(v, i);
    adj[v].emplace_back(u, i);
  }

  for (int i = 0; i < n; i++) {
    if ((int) adj[i].size() > 2) {
      fail();
    }
  }

  string ans (m, '?');
  for (int k = 0; k < 2; k++) {
    // first pass only paths, and only deg 1
    for (int i = 0; i < n; i++) {
      if (!side[i] && (k || adj[i].size() == 1)) {
        vector<int> A, B;
        dfs(i, 1, A, B);
      
        sort(A.begin(), A.end());
        sort(B.begin(), B.end());

        if (A.empty() && B.empty())
          continue;
        else if (A.empty())
          swap(A, B);
        else if (!B.empty() && A[0] > B[0])
          swap(A, B);

        for (int e : A)
          ans[e] = 'A';
        for (int e : B)
          ans[e] = 'B';
      }
    }
  }

  cout << "JAH" << '\n';
  cout << ans << '\n';
}
